@@ -13,7 +13,7 @@
 #' }
 read_umi_tools <- function(filename, dtype = "float32") {
   python_anndata <- reticulate::import("anndata", convert = FALSE)
-  py_to_r(python_anndata$read_umi_tools(
+  py_to_r_ifneedbe(python_anndata$read_umi_tools(
     filename = filename,
     dtype = dtype
   ))
